@@ -234,7 +234,7 @@ over the last four weeks (including today)::
         since = date.today() - timedelta(days=29)
         days = dict((since + timedelta(days=d), 0)
                 for d in range(0, 29))
-        comments = Comment.objects.filter(submit_date=since)
+        comments = Comment.objects.filter(submit_date__gte=since)
         for comment in comments:
             days[comment.submit_date.date()] += 1
         return (
@@ -336,6 +336,6 @@ http://support.geckoboard.com/entries/274940-custom-chart-widget-type-definition
 
 __author__ = "Joost Cassee"
 __email__ = "joost@cassee.net"
-__version__ = "1.2.0"
+__version__ = "1.2.3"
 __copyright__ = "Copyright (C) 2011 Joost Cassee and others"
 __license__ = "MIT License"
